==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/api/apirtschedule/apischedule.go <==
package apirtschedule

import (
	"fmt"
	"time"

	"git.sr.ht/~mil/mobroute/api/apirtinit"
	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"git.sr.ht/~mil/mobroute/util/utillog"
	"github.com/go-playground/validator/v10"
)

func RTSchedule(runtime *apirtinit.MobrouteRuntime, params *ScheduleParams) (*ScheduleResponse, error) {
	utillog.Infoj("Running Schedule API against input", params)

	// Defaults if unset
	params.Time = fif(params.Time != nil, params.Time, ptr(time.Now())) // E.g. now

	var (
		timeYYYYMMDD         = utilfuncs.DayYYYYMMDD(params.Time)
		_, timeUTCOffsetSecs = params.Time.Zone()
		timeSecondsFrom      = timeUTCOffsetSecs + int(utilfuncs.DaySeconds(params.Time))
		timeSecondsTo        = timeSecondsFrom + int(params.MaxSeconds)
	)

	if err := validator.New(validator.WithRequiredStructEnabled()).Struct(params); err != nil {
		return nil, fmt.Errorf("Validation failed request: %v", err)
	} else if err := dbquery.QueryFeedIDsLoadedAndComputed(runtime.DB, params.FeedIDs); err != nil {
		return nil, err
	} else if timezoneStrs, err := dbquery.LoadAgencyTimezones(
		runtime.DB, params.FeedIDs,
	); err != nil {
		return nil, fmt.Errorf("Problem querying timezones from DB: %v", err)
	} else if tzToUTCDeltasMap, err := utilfuncs.TimezoneToUTCDeltaMap(*timezoneStrs, timeYYYYMMDD); err != nil {
		return nil, fmt.Errorf("Coudln't convert timezone strings to UTC deltas: %v", err)
	} else if memConnsVerbose, err := dbquery.LoadConnectionsVerbose(
		runtime.DB, params.FeedIDs, tzToUTCDeltasMap, timeYYYYMMDD, timeSecondsFrom, timeSecondsTo,
		nil, ptr(params.StopIDs),
	); err != nil {
		return nil, err
	} else {
		return &ScheduleResponse{
			Schedule: mapDBTConnectionsVerboseToScheduleDepartures(memConnsVerbose, params.Time),
		}, nil
	}
}

// Essentially just needed to time conversions formatting, DB returns raw
// date-relative UTC seconds, we map this into a native time.Time here
func mapDBTConnectionsVerboseToScheduleDepartures(stoptimes *[]dbt.ConnectionVerbose, beginTime *time.Time) *[]ScheduleDeparture {
	var (
		r                    = []ScheduleDeparture{}
		formatYYYYMMDD       = utilfuncs.DayYYYYMMDD(beginTime)
		formatTZUTCDeltasecs = utilfuncs.DayUTCOffsetSecs(beginTime)
	)

	for _, s := range *stoptimes {
		r = append(r, ScheduleDeparture{
			StopSIDU:       s.FromStopSIDU,
			RouteShortName: s.RouteShortName,
			RouteLongName:  s.RouteLongName,
			TripHeadsign:   s.TripHeadsign,

			DepartureTime: ptr(utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(formatYYYYMMDD, formatTZUTCDeltasecs, s.FromStopDRUTCTime)),
		})
	}

	return &r
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/api/apirtschedule/apischedule.go <==
package apirtschedule

import (
	"fmt"
	"time"

	"git.sr.ht/~mil/mobroute/api/apirtinit"
	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utilfuncs"
	"git.sr.ht/~mil/mobroute/util/utillog"
	"github.com/go-playground/validator/v10"
)

func RTSchedule(runtime *apirtinit.MobrouteRuntime, params *ScheduleParams) (*ScheduleResponse, error) {
	utillog.Infoj("Running RTSchedule against input:", params)

	// Defaults if unset
	params.Time = utilfuncs.Fif(params.Time != nil, params.Time, ptr(time.Now())) // E.g. now

	var (
		timeYYYYMMDD         = utilfuncs.DayYYYYMMDD(params.Time)
		_, timeUTCOffsetSecs = params.Time.Zone()
		timeSecondsFrom      = timeUTCOffsetSecs + int(utilfuncs.DaySeconds(params.Time))
		timeSecondsTo        = timeSecondsFrom + int(params.MaxSeconds)
	)

	if err := validator.New(validator.WithRequiredStructEnabled()).Struct(params); err != nil {
		return nil, fmt.Errorf("Validation failed request: %v", err)
	} else if err := dbquery.QueryFeedIDsLoadedAndComputed(runtime.DB, params.FeedIDs); err != nil {
		return nil, err
	} else if timezoneStrs, err := dbquery.LoadAgencyTimezones(
		runtime.DB, params.FeedIDs,
	); err != nil {
		return nil, fmt.Errorf("Problem querying timezones from DB: %v", err)
	} else if tzToUTCDeltasMap, err := utilfuncs.TimezoneToUTCDeltaMap(*timezoneStrs, timeYYYYMMDD); err != nil {
		return nil, fmt.Errorf("Coudln't convert timezone strings to UTC deltas: %v", err)
	} else if memConnsVerbose, err := dbquery.LoadConnectionsVerbose(
		runtime.DB, params.FeedIDs, tzToUTCDeltasMap, timeYYYYMMDD, timeSecondsFrom, timeSecondsTo,
		nil, ptr(params.StopIDs),
	); err != nil {
		return nil, err
	} else {
		return &ScheduleResponse{
			Schedule: mapDBTConnectionsVerboseToScheduleDepartures(memConnsVerbose, params.Time),
		}, nil
	}
}

// Essentially just needed to time conversions formatting, DB returns raw
// date-relative UTC seconds, we map this into a native time.Time here
func mapDBTConnectionsVerboseToScheduleDepartures(stoptimes *[]dbt.ConnectionVerbose, beginTime *time.Time) *[]ScheduleDeparture {
	var (
		r                    = []ScheduleDeparture{}
		formatYYYYMMDD       = utilfuncs.DayYYYYMMDD(beginTime)
		formatTZUTCDeltasecs = utilfuncs.DayUTCOffsetSecs(beginTime)
	)

	for _, s := range *stoptimes {
		r = append(r, ScheduleDeparture{
			StopSIDU:       s.FromStopSIDU,
			RouteShortName: s.RouteShortName,
			RouteLongName:  s.RouteLongName,
			TripHeadsign:   s.TripHeadsign,

			DepartureTime: ptr(utilfuncs.CreateTimeFromYYYYMMDDZoneSecs(formatYYYYMMDD, formatTZUTCDeltasecs, s.FromStopDRUTCTime)),
		})
	}

	return &r
}
